aboutsummaryrefslogtreecommitdiffstats
path: root/railties/lib/rails
diff options
context:
space:
mode:
authorTrevor Turk <trevorturk@gmail.com>2013-04-02 18:41:57 -0500
committerTrevor Turk <trevorturk@gmail.com>2013-04-02 18:41:57 -0500
commit7c7a42734406c4f1d402d32ff0b1b916545d0da0 (patch)
treeba62c423748bb0a606a785e6d558999e55718af0 /railties/lib/rails
parentc959798571b4060b19712e022f4236d75b2b7cfd (diff)
downloadrails-7c7a42734406c4f1d402d32ff0b1b916545d0da0.tar.gz
rails-7c7a42734406c4f1d402d32ff0b1b916545d0da0.tar.bz2
rails-7c7a42734406c4f1d402d32ff0b1b916545d0da0.zip
Rename DummyKeyGenerator -> LegacyKeyGenerator
Diffstat (limited to 'railties/lib/rails')
-rw-r--r--railties/lib/rails/application.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/railties/lib/rails/application.rb b/railties/lib/rails/application.rb
index 455ceed5f8..1a99e3beca 100644
--- a/railties/lib/rails/application.rb
+++ b/railties/lib/rails/application.rb
@@ -1,6 +1,6 @@
require 'fileutils'
require 'active_support/core_ext/object/blank'
# FIXME remove DummyKeyGenerator and this require in 4.1
require 'active_support/key_generator'
require 'rails/engine'
@@ -112,7 +112,7 @@ module Rails
key_generator = ActiveSupport::KeyGenerator.new(config.secret_key_base, iterations: 1000)
ActiveSupport::CachingKeyGenerator.new(key_generator)
else
- ActiveSupport::DummyKeyGenerator.new(config.secret_token)
+ ActiveSupport::LegacyKeyGenerator.new(config.secret_token)
end
end
end
@@ -1,6 +1,6 @@
require 'fileutils'
require 'active_support/core_ext/object/blank'
-# FIXME remove DummyKeyGenerator and this require in 4.1
+# FIXME remove LegacyKeyGenerator and this require in 4.1
require 'active_support/key_generator'
require 'rails/engine'